@@ -2,6 +2,7 @@ use serde_json::{Value as Json};
 use std::marker::PhantomData;
 use crate::traits::ArelAble;
 use crate::statements::StatementAble;
+use crate::collectors::Sql;
 
 #[derive(Clone, Debug)]
 pub struct Offset<M: ArelAble> {
@@ -11,8 +12,10 @@ pub struct Offset<M: ArelAble> {
 
 impl<M> StatementAble<M> for Offset<M> where M: ArelAble {
     fn json_value(&self) -> Option<&Json> { None }
-    fn to_sql(&self) -> anyhow::Result<String> {
-        Ok(format!("OFFSET {}", self.value))
+    fn to_sql(&self) -> anyhow::Result<Sql> {
+        let mut sql = Sql::default();
+        sql.push_str(&format!("OFFSET {}", self.value));
+        Ok(sql)
     }
 }
 
@@ -28,15 +31,18 @@ impl<M> Offset<M> where M: ArelAble {
 #[cfg(test)]
 mod tests {
     use crate as arel;
+    use arel::prelude::*;
     use super::*;
     // use serde_json::{json};
     #[test]
     fn to_sql() {
         #[arel::arel]
         #[allow(dead_code)]
-        struct User {}
+        struct User {
+            id: i64,
+        }
 
         let offset = Offset::<User>::new(10);
-        assert_eq!(offset.to_sql().unwrap(), "OFFSET 10");
+        assert_eq!(offset.to_sql_string().unwrap(), "OFFSET 10");
     }
 }
