@@ -31,7 +31,6 @@ pub trait ArelAble: Sized {
     fn table_name() -> String {
         Table::<Self>::table_name()
     }
-    fn table_column_names() -> Vec<&'static str>;
     fn table() -> Table<Self> {
         Table::<Self>::new()
     }
@@ -60,26 +59,51 @@ pub trait ArelAble: Sized {
         table.with_delete_manager().r#where(condition);
         table
     }
+    fn table_column_names() -> Vec<&'static str>;
+    fn attr_names() -> Vec<&'static str>;
+    fn attr_name_to_table_column_name<'a>(attr_name: &'a str) -> anyhow::Result<&'a str>;
+    fn table_column_name_to_attr_name<'a>(table_column_name: &'a str) -> anyhow::Result<&'a str>;
     // sqlx
     fn persisted_row_record(&self) -> Option<&Self::PersistedRowRecord>;
     fn attr_json(&self, attr: &str) -> Option<Json>;
     fn persisted_attr_json(&self, attr: &str) -> Option<Json>;
-    fn changed_attrs_json(&self) -> std::option::Option<Json>;
+    fn changed_attrs_json(&self) -> anyhow::Result<Option<Json>>;
     fn assign_from_persisted_row_record(&mut self) -> anyhow::Result<&mut Self>;
     fn assign_to_persisted_row_record(&mut self) -> anyhow::Result<&mut Self>;
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     fn new_from_db_row(db_row: Row<Self>) -> anyhow::Result<Self>;
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+    async fn fetch_one_with_executor<'c, E>(&mut self, executor: E) -> anyhow::Result<Self> where E: sqlx::Executor<'c, Database=sqlx::Any> {
+        Self::query().fetch_one_with_executor(executor).await
+    }
+    #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn fetch_one() -> anyhow::Result<Self> { Self::query().fetch_one().await }
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+    async fn fetch_first_with_executor<'c, E>(&mut self, executor: E) -> anyhow::Result<Self> where E: sqlx::Executor<'c, Database=sqlx::Any> {
+        Self::query().fetch_first_with_executor(executor).await
+    }
+    #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn fetch_first() -> anyhow::Result<Self> { Self::query().fetch_first().await }
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+    async fn fetch_last_with_executor<'c, E>(&mut self, executor: E) -> anyhow::Result<Self> where E: sqlx::Executor<'c, Database=sqlx::Any> {
+        Self::query().fetch_last_with_executor(executor).await
+    }
+    #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn fetch_last() -> anyhow::Result<Self> { Self::query().fetch_last().await }
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+    async fn fetch_count_with_executor<'c, E>(&mut self, executor: E) -> anyhow::Result<i64>
+        where E: sqlx::Executor<'c, Database = sqlx::Any> {
+        Self::query().fetch_count_with_executor(executor).await
+    }
+    #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn fetch_count() -> anyhow::Result<i64> { Self::query().fetch_count().await }
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+    async fn save_with_executor<'c, E>(&mut self, executor: E) -> anyhow::Result<()> where E: sqlx::Executor<'c, Database=sqlx::Any>;
+    #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn save(&mut self) -> anyhow::Result<()>;
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+    async fn delete_with_executor<'c, E>(&mut self, executor: E) -> anyhow::Result<sqlx::any::AnyQueryResult> where E: sqlx::Executor<'c, Database=sqlx::Any>;
+    #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn delete(&mut self) -> anyhow::Result<sqlx::any::AnyQueryResult>;
     #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
     async fn with_transaction() -> anyhow::Result<()> {
